@@ -3,7 +3,7 @@ from django import forms
 #from captcha.fields import CaptchaField
 from django.utils.translation import ugettext_lazy as _ 
 
-from tendenci.core.base.fields import EmailVerificationField
+from tendenci.core.base.fields import EmailVerificationField, CountrySelectField
 
 #from simplemathcaptcha.fields import MathCaptchaField
 from tendenci.core.base.forms import SimpleMathField
@@ -31,7 +31,7 @@ class SubmitContactForm(forms.Form):
     city = forms.CharField(max_length=50, required=False)
     state = forms.CharField(max_length=50, required=False)
     zipcode = forms.CharField(max_length=10, required=False)
-    country = forms.CharField(max_length=100, required=False)
+    country = CountrySelectField(required=False)
 
     phone = forms.CharField(max_length=20, required=False)
     email = EmailVerificationField(label=_("Email"))
